Package: TFHAZ
Type: Package
Title: Transcription Factor High Accumulation Zones
Version: 1.35.0
Author: Alberto Marchesi, Silvia Cascianelli, Marco Masseroli
Maintainer: Gaia Ceddia <gaia.ceddia@polimi.it>
Description: It finds trascription factor (TF) high accumulation DNA zones, 
    i.e., regions along the genome where there is a high presence of different 
    transcription factors. Starting from a dataset containing the genomic
    positions of TF binding regions, for each base of the selected chromosome
    the accumulation of TFs is computed. Three different types of accumulation 
    (TF, region and base accumulation) are available, together with the
    possibility of considering, in the single base accumulation computing, 
    the TFs present not only in that single base, but also in its neighborhood,
    within a window of a given width. Two different methods for the search of TF
    high accumulation DNA zones, called "binding regions" and "overlaps", are 
    available. In addition, some functions are provided in order to analyze, 
    visualize and compare results obtained with different input parameters.
License: Artistic-2.0
Encoding: UTF-8
Imports: GenomicRanges, S4Vectors, grDevices, graphics, stats, utils,
        IRanges, methods, ORFik
biocViews: Software, BiologicalQuestion, Transcription, ChIPSeq,
        Coverage
LazyData: true
Depends: R (>= 3.5.0)
Suggests: BiocStyle, knitr, rmarkdown
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/TFHAZ
git_branch: devel
git_last_commit: 05269b1
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 01:34:18 UTC; biocbuild
